@@ -56,6 +56,7 @@ def _destination_sample(
         alt_dest_col_name,
         estimator,
         chunk_size,
+        chunk_tag,
         trace_label):
     """
 
@@ -94,17 +95,21 @@ def _destination_sample(
     })
     locals_dict.update(skims)
 
+    log_alt_losers = config.setting('log_alt_losers', False)
+
     choices = interaction_sample(
         choosers=trips,
         alternatives=alternatives,
         sample_size=sample_size,
         alt_col_name=alt_dest_col_name,
+        log_alt_losers=log_alt_losers,
         allow_zero_probs=True,
         spec=spec,
         skims=skims,
         locals_d=locals_dict,
-        chunk_size=chunk_size,
-        trace_label=trace_label)
+        chunk_size=chunk_size, chunk_tag=chunk_tag,
+        trace_label=trace_label
+        )
 
     return choices
 
@@ -120,6 +125,8 @@ def destination_sample(
         chunk_size,
         trace_label):
 
+    chunk_tag = 'trip_destination.sample'
+
     skims = skim_hotel.sample_skims(presample=False)
     alt_dest_col_name = model_settings['ALT_DEST_COL_NAME']
 
@@ -133,7 +140,8 @@ def destination_sample(
         alt_dest_col_name,
         estimator,
         chunk_size,
-        trace_label)
+        chunk_tag=chunk_tag,
+        trace_label=trace_label)
 
     return choices
 
@@ -356,8 +364,7 @@ def destination_presample(
         trace_label):
 
     trace_label = tracing.extend_trace_label(trace_label, 'presample')
-
-    logger.info(f"{trace_label} destination_presample")
+    chunk_tag = 'trip_destination.presample'  # distinguish from trip_destination.sample
 
     alt_dest_col_name = model_settings['ALT_DEST_COL_NAME']
     maz_taz = network_los.maz_taz_df[['MAZ', 'TAZ']].set_index('MAZ').TAZ
@@ -387,7 +394,8 @@ def destination_presample(
         alt_dest_col_name,
         estimator,
         chunk_size,
-        trace_label)
+        chunk_tag=chunk_tag,
+        trace_label=trace_label)
 
     # choose a MAZ for each DEST_TAZ choice, choice probability based on MAZ size_term fraction of TAZ total
     maz_sample = choose_MAZ_for_TAZ(taz_sample, size_term_matrix, trips, network_los, alt_dest_col_name, trace_label)
@@ -423,7 +431,7 @@ def trip_destination_sample(
         pick_count : int
             number of duplicate picks for chooser, alt
     """
-    trace_label = tracing.extend_trace_label(trace_label, 'trip_destination_sample')
+    trace_label = tracing.extend_trace_label(trace_label, 'sample')
 
     assert len(trips) > 0
     assert len(alternatives) > 0
@@ -474,7 +482,8 @@ def compute_ood_logsums(
         od_skims,
         locals_dict,
         chunk_size,
-        trace_label):
+        trace_label,
+        chunk_tag):
     """
     Compute one (of two) out-of-direction logsums for destination alternatives
 
@@ -495,7 +504,8 @@ def compute_ood_logsums(
         skims=od_skims,
         locals_d=locals_dict,
         chunk_size=chunk_size,
-        trace_label=trace_label)
+        trace_label=trace_label,
+        chunk_tag=chunk_tag)
 
     assert logsums.index.equals(choosers.index)
 
@@ -526,6 +536,9 @@ def compute_logsums(
     trace_label = tracing.extend_trace_label(trace_label, 'compute_logsums')
     logger.info("Running %s with %d samples", trace_label, destination_sample.shape[0])
 
+    # chunk usage is uniform so better to combine
+    chunk_tag = 'trip_destination.compute_logsums'
+
     # FIXME should pass this in?
     network_los = inject.get_injectable('network_los')
 
@@ -588,7 +601,8 @@ def compute_logsums(
         od_skims,
         locals_dict,
         chunk_size,
-        trace_label=tracing.extend_trace_label(trace_label, 'od'))
+        trace_label=tracing.extend_trace_label(trace_label, 'od'),
+        chunk_tag=chunk_tag)
 
     # - dp_logsums
     dp_skims = {
@@ -611,7 +625,8 @@ def compute_logsums(
         dp_skims,
         locals_dict,
         chunk_size,
-        trace_label=tracing.extend_trace_label(trace_label, 'dp'))
+        trace_label=tracing.extend_trace_label(trace_label, 'dp'),
+        chunk_tag=chunk_tag)
 
     return destination_sample
 
@@ -637,6 +652,7 @@ def trip_destination_simulate(
         destination alt chosen
     """
     trace_label = tracing.extend_trace_label(trace_label, 'trip_dest_simulate')
+    chunk_tag = 'trip_destination.simulate'
 
     spec = simulate.spec_for_segment(model_settings, spec_id='DESTINATION_SPEC',
                                      segment_name=primary_purpose, estimator=estimator)
@@ -656,16 +672,19 @@ def trip_destination_simulate(
     })
     locals_dict.update(skims)
 
+    log_alt_losers = config.setting('log_alt_losers', False)
+
     destinations = interaction_sample_simulate(
         choosers=trips,
         alternatives=destination_sample,
         spec=spec,
         choice_column=alt_dest_col_name,
+        log_alt_losers=log_alt_losers,
         want_logsums=want_logsums,
         allow_zero_probs=True, zero_prob_choice_val=NO_DESTINATION,
         skims=skims,
         locals_d=locals_dict,
-        chunk_size=chunk_size,
+        chunk_size=chunk_size, chunk_tag=chunk_tag,
         trace_label=trace_label,
         trace_choice_name='trip_dest',
         estimator=estimator)
