@@ -279,7 +279,7 @@ def schedule_trips_in_leg(
         trips,
         probs_spec,
         model_settings,
-        last_iteration,
+        is_last_iteration,
         trace_hh_id, trace_label):
     """
 
@@ -289,7 +289,7 @@ def schedule_trips_in_leg(
     trips
     probs_spec
     depart_alt_base
-    last_iteration
+    is_last_iteration
     trace_hh_id
     trace_label
 
@@ -319,56 +319,60 @@ def schedule_trips_in_leg(
     result_list.append(choices)
     trips = trips[~no_scheduling]
 
-    # add next_trip_id temp column (temp as trips is now a copy, as result of slicing)
-    trips = trips.sort_index()
-    trips['next_trip_id'] = np.roll(trips.index, -1 if outbound else 1)
-    is_final = (trips.trip_num == trips.trip_count) if outbound else (trips.trip_num == 1)
-    trips.next_trip_id = trips.next_trip_id.where(~is_final, NO_TRIP_ID)
+    with chunk.chunk_log(trace_label):
 
-    # iterate over outbound trips in ascending trip_num order, skipping the initial trip
-    # iterate over inbound trips in descending trip_num order, skipping the finial trip
-    first_trip_in_leg = True
-    for i in range(trips.trip_num.min(), trips.trip_num.max() + 1):
+        # add next_trip_id temp column (temp as trips is now a copy, as result of slicing)
+        trips = trips.sort_index()
+        trips['next_trip_id'] = np.roll(trips.index, -1 if outbound else 1)
+        is_final = (trips.trip_num == trips.trip_count) if outbound else (trips.trip_num == 1)
+        trips.next_trip_id = trips.next_trip_id.where(~is_final, NO_TRIP_ID)
 
-        if outbound:
-            nth_trips = trips[trips.trip_num == i]
-        else:
-            nth_trips = trips[trips.trip_num == trips.trip_count - i]
+        # iterate over outbound trips in ascending trip_num order, skipping the initial trip
+        # iterate over inbound trips in descending trip_num order, skipping the finial trip
+        first_trip_in_leg = True
+        for i in range(trips.trip_num.min(), trips.trip_num.max() + 1):
 
-        nth_trace_label = tracing.extend_trace_label(trace_label, 'num_%s' % i)
+            if outbound:
+                nth_trips = trips[trips.trip_num == i]
+            else:
+                nth_trips = trips[trips.trip_num == trips.trip_count - i]
 
-        with chunk.chunk_log(nth_trace_label):
-            choices = schedule_nth_trips(
-                nth_trips,
-                probs_spec,
-                model_settings,
-                first_trip_in_leg=first_trip_in_leg,
-                report_failed_trips=last_iteration,
-                trace_hh_id=trace_hh_id,
-                trace_label=nth_trace_label)
+            nth_trace_label = tracing.extend_trace_label(trace_label, 'num_%s' % i)
 
-        # if outbound, this trip's depart constrains next trip's earliest depart option
-        # if inbound, we are handling in reverse order, so it constrains latest depart instead
-        ADJUST_NEXT_DEPART_COL = 'earliest' if outbound else 'latest'
+            with chunk.chunk_log(nth_trace_label, chunk_tag=trace_label):
+                choices = schedule_nth_trips(
+                    nth_trips,
+                    probs_spec,
+                    model_settings,
+                    first_trip_in_leg=first_trip_in_leg,
+                    report_failed_trips=is_last_iteration,
+                    trace_hh_id=trace_hh_id,
+                    trace_label=nth_trace_label)
 
-        # most initial departure (when no choice was made because all probs were zero)
-        if last_iteration and (failfix == FAILFIX_CHOOSE_MOST_INITIAL):
-            choices = choices.reindex(nth_trips.index)
-            logger.warning("%s coercing %s depart choices to most initial" %
-                           (nth_trace_label, choices.isna().sum()))
-            choices = choices.fillna(trips[ADJUST_NEXT_DEPART_COL])
+            # if outbound, this trip's depart constrains next trip's earliest depart option
+            # if inbound, we are handling in reverse order, so it constrains latest depart instead
+            ADJUST_NEXT_DEPART_COL = 'earliest' if outbound else 'latest'
 
-        # adjust allowed depart range of next trip
-        has_next_trip = (nth_trips.next_trip_id != NO_TRIP_ID)
-        if has_next_trip.any():
-            next_trip_ids = nth_trips.next_trip_id[has_next_trip]
-            # patch choice any trips with next_trips that weren't scheduled
-            trips.loc[next_trip_ids, ADJUST_NEXT_DEPART_COL] = \
-                choices.reindex(next_trip_ids.index).fillna(trips[ADJUST_NEXT_DEPART_COL]).values
+            # most initial departure (when no choice was made because all probs were zero)
+            if is_last_iteration and (failfix == FAILFIX_CHOOSE_MOST_INITIAL):
+                choices = choices.reindex(nth_trips.index)
+                logger.warning("%s coercing %s depart choices to most initial" %
+                               (nth_trace_label, choices.isna().sum()))
+                choices = choices.fillna(trips[ADJUST_NEXT_DEPART_COL])
 
-        result_list.append(choices)
+            # adjust allowed depart range of next trip
+            has_next_trip = (nth_trips.next_trip_id != NO_TRIP_ID)
+            if has_next_trip.any():
+                next_trip_ids = nth_trips.next_trip_id[has_next_trip]
+                # patch choice any trips with next_trips that weren't scheduled
+                trips.loc[next_trip_ids, ADJUST_NEXT_DEPART_COL] = \
+                    choices.reindex(next_trip_ids.index).fillna(trips[ADJUST_NEXT_DEPART_COL]).values
 
-        first_trip_in_leg = False
+            result_list.append(choices)
+
+            chunk.log_df(trace_label, f'result_list', result_list)
+
+            first_trip_in_leg = False
 
     if len(result_list) > 1:
         choices = pd.concat(result_list)
@@ -376,60 +380,18 @@ def schedule_trips_in_leg(
     return choices
 
 
-def trip_scheduling_calc_row_size(trips, spec, trace_label):
-
-    sizer = chunk.RowSizeEstimator(trace_label)
-
-    # NOTE we chunk chunk_id
-    # scale row_size by average number of chooser rows per chunk_id
-    num_choosers = trips['chunk_id'].max() + 1
-    rows_per_chunk_id = len(trips) / num_choosers
-
-    # only non-initial trips require scheduling, segment handing first such trip in tour will use most space
-    outbound_chooser = (trips.trip_num == 2) & trips.outbound & (trips.primary_purpose != 'atwork')
-    inbound_chooser = (trips.trip_num == trips.trip_count-1) & ~trips.outbound & (trips.primary_purpose != 'atwork')
-
-    # furthermore, inbound and outbound are scheduled independently
-    if outbound_chooser.sum() > inbound_chooser.sum():
-        is_chooser = outbound_chooser
-        logger.debug(f"{trace_label} {is_chooser.sum()} outbound_choosers of {len(trips)} require scheduling")
-    else:
-        is_chooser = inbound_chooser
-        logger.debug(f"{trace_label} {is_chooser.sum()} inbound_choosers of {len(trips)} require scheduling")
-
-    chooser_fraction = is_chooser.sum()/len(trips)
-    logger.debug(f"{trace_label} chooser_fraction {chooser_fraction *100}%")
-
-    chooser_row_size = len(trips.columns) + len(spec.columns) - len(PROBS_JOIN_COLUMNS)
-    sizer.add_elements(chooser_fraction * chooser_row_size, 'choosers')
-
-    # might be clipped to fewer but this is worst case
-    chooser_probs_row_size = len(spec.columns) - len(PROBS_JOIN_COLUMNS)
-    sizer.add_elements(chooser_fraction * chooser_probs_row_size, 'chooser_probs')
-
-    sizer.add_elements(chooser_fraction, 'choices')
-    sizer.add_elements(chooser_fraction, 'rands')
-    sizer.add_elements(chooser_fraction, 'failed')
-
-    row_size = sizer.get_hwm()
-    row_size = row_size * rows_per_chunk_id
-
-    return row_size
-
-
 def run_trip_scheduling(
         trips,
         tours,
         probs_spec,
         model_settings,
         estimator,
-        last_iteration,
+        is_last_iteration,
         chunk_size,
+        chunk_tag,
         trace_hh_id,
         trace_label):
 
-    row_size = chunk_size and trip_scheduling_calc_row_size(trips, probs_spec, trace_label)
-
     # only non-initial trips require scheduling, segment handing first such trip in tour will use most space
     # is_outbound_chooser = (trips.trip_num > 1) & trips.outbound & (trips.primary_purpose != 'atwork')
     # is_inbound_chooser = (trips.trip_num < trips.trip_count) & ~trips.outbound & (trips.primary_purpose != 'atwork')
@@ -437,35 +399,39 @@ def run_trip_scheduling(
 
     result_list = []
     for i, trips_chunk, chunk_trace_label \
-            in chunk.adaptive_chunked_choosers_by_chunk_id(trips, chunk_size, row_size, trace_label):
+            in chunk.adaptive_chunked_choosers_by_chunk_id(trips, chunk_size, trace_label, chunk_tag):
 
         if trips_chunk.outbound.any():
+            leg_chunk = trips_chunk[trips_chunk.outbound]
             leg_trace_label = tracing.extend_trace_label(chunk_trace_label, 'outbound')
-            with chunk.chunk_log(leg_trace_label):
-                choices = \
-                    schedule_trips_in_leg(
-                        outbound=True,
-                        trips=trips_chunk[trips_chunk.outbound],
-                        probs_spec=probs_spec,
-                        model_settings=model_settings,
-                        last_iteration=last_iteration,
-                        trace_hh_id=trace_hh_id,
-                        trace_label=leg_trace_label)
-                result_list.append(choices)
+            choices = \
+                schedule_trips_in_leg(
+                    outbound=True,
+                    trips=leg_chunk,
+                    probs_spec=probs_spec,
+                    model_settings=model_settings,
+                    is_last_iteration=is_last_iteration,
+                    trace_hh_id=trace_hh_id,
+                    trace_label=leg_trace_label)
+            result_list.append(choices)
+
+            chunk.log_df(trace_label, f'result_list', result_list)
 
         if (~trips_chunk.outbound).any():
+            leg_chunk = trips_chunk[~trips_chunk.outbound]
             leg_trace_label = tracing.extend_trace_label(chunk_trace_label, 'inbound')
-            with chunk.chunk_log(leg_trace_label):
-                choices = \
-                    schedule_trips_in_leg(
-                        outbound=False,
-                        trips=trips_chunk[~trips_chunk.outbound],
-                        probs_spec=probs_spec,
-                        model_settings=model_settings,
-                        last_iteration=last_iteration,
-                        trace_hh_id=trace_hh_id,
-                        trace_label=leg_trace_label)
-                result_list.append(choices)
+            choices = \
+                schedule_trips_in_leg(
+                    outbound=False,
+                    trips=leg_chunk,
+                    probs_spec=probs_spec,
+                    model_settings=model_settings,
+                    is_last_iteration=is_last_iteration,
+                    trace_hh_id=trace_hh_id,
+                    trace_label=leg_trace_label)
+            result_list.append(choices)
+
+            chunk.log_df(trace_label, f'result_list', result_list)
 
     choices = pd.concat(result_list)
 
@@ -564,11 +530,15 @@ def trip_scheduling(
     while (i < max_iterations) and not trips_df.empty:
 
         i += 1
-        last_iteration = (i == max_iterations)
+        is_last_iteration = (i == max_iterations)
 
         trace_label_i = tracing.extend_trace_label(trace_label, "i%s" % i)
         logger.info("%s scheduling %s trips", trace_label_i, trips_df.shape[0])
 
+        # first iteration gets its own chunk_tag and all subsequent iterations are aggregated
+        # subsequent iterations on failed trips have somewhat different overhead profile than initial batch
+        chunk_tag = "trip_scheduling_1" if i == 1 else "trip_scheduling_n"
+
         choices = \
             run_trip_scheduling(
                 trips_df,
@@ -576,16 +546,17 @@ def trip_scheduling(
                 probs_spec,
                 model_settings,
                 estimator=estimator,
-                last_iteration=last_iteration,
+                is_last_iteration=is_last_iteration,
                 trace_hh_id=trace_hh_id,
                 chunk_size=chunk_size,
+                chunk_tag=chunk_tag,
                 trace_label=trace_label_i)
 
         # boolean series of trips whose individual trip scheduling failed
         failed = choices.reindex(trips_df.index).isnull()
         logger.info("%s %s failed", trace_label_i, failed.sum())
 
-        if not last_iteration:
+        if not is_last_iteration:
             # boolean series of trips whose leg scheduling failed
             failed_cohorts = failed_trip_cohorts(trips_df, failed)
             trips_df = trips_df[failed_cohorts]
