@@ -2,7 +2,14 @@
 # See full license in LICENSE.txt.
 import logging
 
-from . import orca
+try:
+    # use orca module if installed
+    import orca
+    import orca.orca as _ORCA
+except ModuleNotFoundError:
+    # otherwise use local copy
+    from . import orca
+    from . import orca as _ORCA
 
 _DECORATED_STEPS = {}
 _DECORATED_TABLES = {}
@@ -128,7 +135,7 @@ def get_injectable(name, default=_NO_DEFAULT):
 
 def remove_injectable(name):
 
-    orca._INJECTABLES.pop(name, None)
+    _ORCA._INJECTABLES.pop(name, None)
 
 
 def reinject_decorated_tables():
@@ -139,10 +146,10 @@ def reinject_decorated_tables():
     logger.info("reinject_decorated_tables")
 
     # need to clear any non-decorated tables that were added during the previous run
-    orca._TABLES.clear()
-    orca._COLUMNS.clear()
-    orca._TABLE_CACHE.clear()
-    orca._COLUMN_CACHE.clear()
+    _ORCA._TABLES.clear()
+    _ORCA._COLUMNS.clear()
+    _ORCA._TABLE_CACHE.clear()
+    _ORCA._COLUMN_CACHE.clear()
 
     for name, func in _DECORATED_TABLES.items():
         logger.debug("reinject decorated table %s" % name)
@@ -182,4 +189,4 @@ def get_step_arg(arg_name, default=_NO_DEFAULT):
 def dump_state():
 
     print("_DECORATED_STEPS", list(_DECORATED_STEPS.keys()))
-    print("orca._STEPS", list(orca._STEPS.keys()))
+    print("_ORCA._STEPS", list(_ORCA._STEPS.keys()))
